
# API

```{eval-rst}
.. automodule:: pyqrlew
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.io.PostgreSQL
    :members:
```

```{eval-rst}
.. autoclass:: pyqrlew.io.SQLite
    :members:
```

```{eval-rst}
.. autofunction:: pyqrlew.io.dataset
```

<!-- ```{eval-rst}
.. autoclass:: pyqrlew.Relation
    :members:
``` -->
